﻿using System.Web;

using CMS.PortalControls;
using CMS.GlobalHelper;
using CMS.CMSHelper;
using CMS.PortalEngine;
using System;

public partial class CMSWebParts_General_MobileDeviceRedirection : CMSAbstractWebPart
{
    #region Webpart properties

    /// <summary>
    /// URL to which should be mobile device redirected
    /// </summary>
    public string RedirectionURL
    {
        get
        {
            return ValidationHelper.GetString(this.GetValue("RedirectionURL"), "");
        }
        set
        {
            this.SetValue("RedirectionURL", value);
        }
    }

    #endregion


    #region Webpart methods

    /// <summary>
    /// Content loaded event handler
    /// </summary>
    public override void OnContentLoaded()
    {
        base.OnContentLoaded();
        SetupControl();
    }


    /// <summary>
    /// Initializes the control properties
    /// </summary>
    protected void SetupControl()
    {
        if (!this.StopProcessing)
        {
            // Check if visitor use mobile device
            if (BrowserHelper.IsMobileDevice())
            {
                // Trim blank characters
                string rawURL = this.RedirectionURL.Trim();

                // Get redirect cookie
                string redirected = CookieHelper.GetValue("CMSMobileRedirected");

                // Check if some address is specified
                if ((rawURL.Length > 0) &&
                    (CMSContext.ViewMode == ViewModeEnum.LiveSite) &&
                     String.IsNullOrEmpty(redirected))
                {
                    string newURL = UrlHelper.ResolveUrl(rawURL);

                    // If current URL is same as set, no redirection is done
                    if ((UrlHelper.CurrentURL != newURL) &&
                        (UrlHelper.GetAbsoluteUrl(UrlHelper.CurrentURL) != newURL))
                    {
                        // Set redirected cookie
                        CookieHelper.SetValue("CMSMobileRedirected", "true", DateTimeHelper.ZERO_TIME);
                        UrlHelper.ResponseRedirect(newURL);
                    }
                }
            }
        }
    }

    #endregion
}
