UPDATE CMS_Query
SET QueryText = 
'SELECT ##TOPN##  IsSecuredNode, DocumentStylesheetID, DocumentPageTemplateID, NodeDocType, NodeHeadTags, NodeCacheMinutes, DocumentPageTitle, DocumentPageKeyWords, DocumentPageDescription, NodeBodyElementAttributes, RequiresSSL, NodeID, DocumentID, DocumentCulture, NodeACLID, NodeLinkedNodeID, ClassName, NodeAliasPath FROM View_CMS_Tree_Joined WHERE ##WHERE## ORDER BY ##ORDERBY##' WHERE QueryName = 'selectuppertree' AND ClassID = (SELECT ClassID FROM CMS_Class WHERE ClassName=N'CMS.Document')
GO

-- Inserting Resource strings
DECLARE @stringId AS int;
DECLARE @cultureId AS int;
DECLARE @cultureCode AS nvarchar(50);

-- Change value of this parameter if your default UI culture is not 'en-US' (see details in hotfix instructions)
SET @cultureCode = 'en-US';

-- Get culture ID
SET @cultureID = (SELECT UICultureID FROM [CMS_UICulture] WHERE UICultureCode=@cultureCode);

-- Check if resource string exists
SET @stringId = (SELECT StringID FROM [CMS_ResourceString] LEFT JOIN [CMS_ResourceTranslation] ON StringID=TranslationStringID WHERE StringKey = N'UserControlSelector.RequireFileName' AND TranslationUICultureID = @cultureID);
IF  @stringId IS NULL
BEGIN
-- Insert resource string
INSERT INTO [CMS_ResourceString]
           ([StringKey]
           ,[StringIsCustom]
           ,[StringLoadGeneration])
     VALUES
           ('UserControlSelector.RequireFileName'
           ,0
           ,0)

SET @stringId = scope_identity();

-- Insert translation
INSERT INTO [CMS_ResourceTranslation]
           ([TranslationStringID]
           ,[TranslationUICultureID]
           ,[TranslationText])
     VALUES
           (@stringId
           ,@cultureId
           ,'Please enter some file name.')
END

-- Check if resource string exists
SET @stringId = (SELECT StringID FROM [CMS_ResourceString] LEFT JOIN [CMS_ResourceTranslation] ON StringID=TranslationStringID WHERE StringKey = N'UserControlSelector.RequireFolderName' AND TranslationUICultureID = @cultureID);
IF  @stringId IS NULL
BEGIN
-- Insert resource string
INSERT INTO [CMS_ResourceString]
           ([StringKey]
           ,[StringIsCustom]
           ,[StringLoadGeneration])
     VALUES
           ('UserControlSelector.RequireFolderName'
           ,0
           ,0)

SET @stringId = scope_identity();

-- Insert translation
INSERT INTO [CMS_ResourceTranslation]
           ([TranslationStringID]
           ,[TranslationUICultureID]
           ,[TranslationText])
     VALUES
           (@stringId
           ,@cultureId
           ,'Please enter some folder name.')
END

-- Check if resource string exists
SET @stringId = (SELECT StringID FROM [CMS_ResourceString] LEFT JOIN [CMS_ResourceTranslation] ON StringID=TranslationStringID WHERE StringKey = N'dialogs.filesystem.ExcludedExtension' AND TranslationUICultureID = @cultureID);
IF  @stringId IS NULL
BEGIN
-- Insert resource string
INSERT INTO [CMS_ResourceString]
           ([StringKey]
           ,[StringIsCustom]
           ,[StringLoadGeneration])
     VALUES
           ('dialogs.filesystem.ExcludedExtension'
           ,0
           ,0)

SET @stringId = scope_identity();

-- Insert translation
INSERT INTO [CMS_ResourceTranslation]
           ([TranslationStringID]
           ,[TranslationUICultureID]
           ,[TranslationText])
     VALUES
           (@stringId
           ,@cultureId
           ,'Entered file name extension is in list of excluded extensions: %%extensions%%, please enter filename with other extension.')
END

-- Check if resource string exists
SET @stringId = (SELECT StringID FROM [CMS_ResourceString] LEFT JOIN [CMS_ResourceTranslation] ON StringID=TranslationStringID WHERE StringKey = N'dialogs.filesystem.NotAllowedExtension' AND TranslationUICultureID = @cultureID);
IF  @stringId IS NULL
BEGIN
-- Insert resource string
INSERT INTO [CMS_ResourceString]
           ([StringKey]
           ,[StringIsCustom]
           ,[StringLoadGeneration])
     VALUES
           ('dialogs.filesystem.NotAllowedExtension'
           ,0
           ,0)

SET @stringId = scope_identity();

-- Insert translation
INSERT INTO [CMS_ResourceTranslation]
           ([TranslationStringID]
           ,[TranslationUICultureID]
           ,[TranslationText])
     VALUES
           (@stringId
           ,@cultureId
           ,'Please enter a file name with an allowed extension. Allowed extensions: %%extensions%%.')
END

-- Check if resource string exists
SET @stringId = (SELECT StringID FROM [CMS_ResourceString] LEFT JOIN [CMS_ResourceTranslation] ON StringID=TranslationStringID WHERE StringKey = N'dialogs.filesystem.NotAllowedFolder' AND TranslationUICultureID = @cultureID);
IF  @stringId IS NULL
BEGIN
-- Insert resource string
INSERT INTO [CMS_ResourceString]
           ([StringKey]
           ,[StringIsCustom]
           ,[StringLoadGeneration])
     VALUES
           ('dialogs.filesystem.NotAllowedFolder'
           ,0
           ,0)

SET @stringId = scope_identity();

-- Insert translation
INSERT INTO [CMS_ResourceTranslation]
           ([TranslationStringID]
           ,[TranslationUICultureID]
           ,[TranslationText])
     VALUES
           (@stringId
           ,@cultureId
           ,'Entered folder name path or its part is not allowed.')
END

-- Check if resource string exists
SET @stringId = (SELECT StringID FROM [CMS_ResourceString] LEFT JOIN [CMS_ResourceTranslation] ON StringID=TranslationStringID WHERE StringKey = N'importconfiguration.securityerror' AND TranslationUICultureID = @cultureID);
IF  @stringId IS NULL
BEGIN
-- Insert resource string
INSERT INTO [CMS_ResourceString]
           ([StringKey]
           ,[StringIsCustom]
           ,[StringLoadGeneration])
     VALUES
           ('importconfiguration.securityerror'
           ,0
           ,0)

SET @stringId = scope_identity();

-- Insert translation
INSERT INTO [CMS_ResourceTranslation]
           ([TranslationStringID]
           ,[TranslationUICultureID]
           ,[TranslationText])
     VALUES
           (@stringId
           ,@cultureId
           ,'Unable to get list of import packages due to insufficient permissions for the ''{0}'' folder.')
END


GO

-- Insert new DeleteArchived query 
DECLARE @classID int
SET @classID = (SELECT ClassID FROM CMS_Class WHERE ClassName LIKE 'cms.email')

IF  (SELECT TOP 1 QueryName FROM [CMS_Query] WHERE ClassID = @classID AND QueryName LIKE 'deletearchived') IS NULL
BEGIN

	INSERT INTO [CMS_Query]
				(
				[QueryName],
				[QueryTypeID],
				[QueryText],
				[QueryRequiresTransaction],
				[ClassID],
				[QueryIsLocked],
				[QueryLastModified],
				[QueryGUID],
				[QueryLoadGeneration]
				)
		  VALUES
				(
				 'deletearchived',
				 1,
				 'Proc_CMS_Email_DeleteArchived',
				 0,
				 @classID,
				 1,
				 getDate(),
				 newId(),
				 2
				)
END				
GO

-- Check if Stored Procedure already exists
IF (SELECT TOP 1 Name FROM SysObjects WHERE Type = 'P' and Name='Proc_CMS_Email_DeleteArchived') IS NOT NULL
BEGIN
DROP PROCEDURE [Proc_CMS_Email_DeleteArchived]
END

SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE PROCEDURE [Proc_CMS_Email_DeleteArchived]
	-- Procedure parameters
	@SiteID int	= 0,
	@ExpiryDate datetime,
	@EmailStatus int = 3
AS
BEGIN
SET NOCOUNT ON;
	-- Declare table for emails
	DECLARE @emails TABLE ( EmailID int not null ) 
	BEGIN
		-- Get global e-mails
		IF ((@SiteID = 0) OR (@SiteID IS NULL))
			INSERT INTO @emails 
				SELECT EmailID FROM CMS_Email 
				WHERE EmailLastSendAttempt <= @ExpiryDate
					AND (EmailSiteID IS NULL)
					AND EmailStatus = @EmailStatus
		-- Get all e-mails attached to the site			
		ELSE                   
			INSERT INTO @emails 
				SELECT EmailID FROM CMS_Email 
				WHERE EmailLastSendAttempt <= @ExpiryDate
					AND EmailSiteID = @SiteID
					AND EmailStatus = @EmailStatus
	END
      
	BEGIN TRANSACTION
          
	-- Delete attachment binding 
	DELETE FROM [CMS_AttachmentForEmail] WHERE EmailID IN (SELECT EmailID FROM @emails)
	-- Delete user binding
	DELETE FROM [CMS_EmailUser] WHERE EmailID IN (SELECT EmailID FROM @emails)
	-- Delete all attachments that have no bindings
	DELETE FROM CMS_EmailAttachment WHERE AttachmentID NOT IN (SELECT DISTINCT AttachmentID FROM CMS_AttachmentForEmail)
	-- Delete e-mails
	DELETE FROM [CMS_Email] WHERE EmailID IN (SELECT EmailID FROM @emails)
      
	COMMIT TRANSACTION;
END
GO



ALTER PROCEDURE [Proc_CMS_Document_UpdateDocumentNamePath]
	@OriginalNodeID int,
	@SiteID int,
	@DefaultCultureCode nvarchar(10)
AS
BEGIN
	/* Get all starting paths to process */
	DECLARE @nodesTable TABLE (
		NodeAliasPath nvarchar(450)
	);
	
	/* Get the nodes list */
	INSERT INTO @nodesTable SELECT NodeAliasPath FROM CMS_Tree WHERE NodeID = @OriginalNodeID OR NodeLinkedNodeID = @OriginalNodeID ORDER BY NodeAliasPath;
	/* Declare the cursor to loop through the table */
	DECLARE @nodeCursor CURSOR;
    SET @nodeCursor = CURSOR FOR SELECT NodeAliasPath FROM @nodesTable;
	
	DECLARE @startingAliasPath nvarchar(450)
	
	/* Loop through the table */
	OPEN @nodeCursor
	FETCH NEXT FROM @nodeCursor INTO @startingAliasPath;
	WHILE @@FETCH_STATUS = 0
	BEGIN
		/* Get the list of nodes to update */
		DECLARE @processDocuments TABLE (
				DocumentID int,
				NodeParentID int,
				DocumentCulture nvarchar(10),
				DocumentUseNamePathForUrlPath bit,
				DocumentUrlPath nvarchar(450)
		);

		INSERT INTO @processDocuments SELECT DocumentID, NodeParentID, DocumentCulture, DocumentUseNamePathForUrlPath, DocumentUrlPath FROM View_CMS_Tree_Joined WHERE NodeAliasPath LIKE @startingAliasPath + '/%' OR NodeAliasPath = @startingAliasPath AND NodeSiteID = @SiteID ORDER BY NodeLinkedNodeID DESC, NodeLevel ASC
		
		/* Loop through documents */
		DECLARE @documentId int;
		DECLARE @nodeParentId int;
		DECLARE @documentCulture nvarchar(10);
		DECLARE @useNamePathForUrlPath bit;
		DECLARE @documentUrlPath nvarchar(450);

		DECLARE @documentCursor CURSOR;
		SET @documentCursor = CURSOR FOR SELECT DocumentID, NodeParentID, DocumentCulture, DocumentUseNamePathForUrlPath, DocumentUrlPath FROM @processDocuments;
		
		OPEN @documentCursor
		FETCH NEXT FROM @documentCursor INTO @documentId, @nodeParentId, @documentCulture, @useNamePathForUrlPath, @documentUrlPath
		WHILE @@FETCH_STATUS = 0
		BEGIN
			/* Update the name path */
			DECLARE @parentNamePath nvarchar(1500);
			DECLARE @parentUseNamePathForUrlPath bit;
			DECLARE @parentUrlPath nvarchar(450);

			SELECT @parentNamePath = DocumentNamePath, @parentUseNamePathForUrlPath = DocumentUseNamePathForUrlPath, @parentUrlPath = DocumentUrlPath FROM
				(SELECT TOP 1 DocumentNamePath, DocumentUseNamePathForUrlPath, DocumentUrlPath FROM (
					(SELECT DocumentNamePath, DocumentUseNamePathForUrlPath, DocumentUrlPath, 1 AS Priority FROM View_CMS_Tree_Joined WHERE NodeID = @nodeParentId AND DocumentCulture = @documentCulture AND NodeAliasPath <> '/') UNION ALL 
					(SELECT DocumentNamePath, DocumentUseNamePathForUrlPath, DocumentUrlPath, 2 AS Priority FROM View_CMS_Tree_Joined WHERE NodeID = @nodeParentId AND DocumentCulture = @DefaultCultureCode AND NodeAliasPath <> '/') UNION ALL
					(SELECT DocumentNamePath, DocumentUseNamePathForUrlPath, DocumentUrlPath, 3 AS Priority FROM View_CMS_Tree_Joined WHERE NodeID = @nodeParentId AND NodeAliasPath <> '/') UNION ALL
					(SELECT '', 0, '', 4 AS Priority)
				) ParentPaths ORDER BY Priority ASC) TopParentPath;
		
			/* Update the URL path (parent URL path + last part of URL path */
			IF @useNamePathForUrlPath = 1 AND @parentUseNamePathForUrlPath = 1 AND @parentUrlPath <> '' AND  @documentUrlPath <> ''
			BEGIN
				SET @documentUrlPath = @parentUrlPath + '/' + RIGHT(@documentUrlPath, CHARINDEX('/', REVERSE(@documentUrlPath)) - 1);
			END;

			/* Update the document */
			UPDATE CMS_Document SET DocumentNamePath = @parentNamePath + '/' + DocumentName, DocumentUrlPath = @documentUrlPath WHERE DocumentID = @documentId
			
			FETCH NEXT FROM @documentCursor INTO @documentId, @nodeParentId, @documentCulture, @useNamePathForUrlPath, @documentUrlPath
		END

		CLOSE @documentCursor;
		DEALLOCATE @documentCursor;

		FETCH NEXT FROM @nodeCursor INTO @startingAliasPath;
	END
	CLOSE @nodeCursor;
	DEALLOCATE @nodeCursor;
END
GO

-- Insert stored procedure for ACLs
IF (SELECT TOP 1 Name FROM SysObjects WHERE Type = 'P' and Name='Proc_CMS_ACL_RemoveACLID') IS NOT NULL
BEGIN
DROP PROCEDURE [Proc_CMS_ACL_RemoveACLID]
END
GO

CREATE PROCEDURE [Proc_CMS_ACL_RemoveACLID]
	@ACLID nvarchar(450),
	@SiteID int, 
	@NodeAliasPath nvarchar(450)	
AS
BEGIN
	DECLARE @ACLInheritedACLs nvarchar(450);
	DECLARE @ACL int;
	DECLARE @aclCursor CURSOR;
	
	SET @aclCursor = CURSOR FOR SELECT ACLInheritedACLs,ACLID FROM CMS_ACL WHERE CMS_ACL.ACLID IN (SELECT DISTINCT		CMS_Tree.NodeACLID FROM CMS_Tree INNER JOIN CMS_ACL ON CMS_ACL.ACLID = CMS_Tree.NodeACLID WHERE NodeSiteID = @SiteID AND NodeAliasPath LIKE @NodeAliasPath)
	OPEN @aclCursor
	FETCH NEXT FROM @aclCursor INTO @ACLInheritedACLs, @ACL;

	WHILE @@FETCH_STATUS = 0
	BEGIN
		SET @ACLInheritedACLs = REPLACE(',' + @ACLInheritedACLs + ',', ',' + @ACLID + ',', ',')
		SET @ACLInheritedACLs = SUBSTRING(@ACLInheritedACLs, 2, LEN(@ACLInheritedACLs)-2)
		UPDATE CMS_ACL SET ACLInheritedACLs = @ACLInheritedACLs WHERE ACLID = @ACL

		FETCH NEXT FROM @aclCursor INTO @ACLInheritedACLs, @ACL
	END

	CLOSE @aclCursor;
	DEALLOCATE @aclCursor;	
END
GO

-- Update particular query
UPDATE CMS_Query SET QueryText='Proc_CMS_ACL_RemoveACLID', QueryTypeID = 1 WHERE QueryName = 'removeaclid' AND ClassID = (SELECT ClassID FROM CMS_Class WHERE ClassName=N'CMS.ACL')
GO

-- Update settings key validation regex
UPDATE	[CMS_SettingsKey] SET [KeyValidation] = '\d+' WHERE [KeyName] = 'CMSLogSize' AND [SiteID] IS NULL
GO

ALTER PROCEDURE [Proc_CMS_User_IsAuthorizedPerNode]
@UserID int, @NodeID int, @PermissionName nvarchar(100), @GenericRoles nvarchar(200), @SiteID int
AS
BEGIN
	DECLARE @SelectedUserID int;
	SELECT TOP 1 @SelectedUserID = CMS_User.UserID
	FROM CMS_User
	INNER JOIN CMS_UserRole on CMS_UserRole.UserID = cms_user.UserID
	INNER JOIN CMS_Role on CMS_Role.RoleID = CMS_UserRole.RoleID
	INNER JOIN CMS_RolePermission on CMS_RolePermission.RoleID = CMS_Role.RoleID
	INNER JOIN CMS_Permission on CMS_Permission.permissionid = CMS_RolePermission.PermissionID
	INNER JOIN CMS_Class on CMS_Class.ClassID = CMS_Permission.ClassID
	INNER JOIN CMS_Tree on CMS_Tree.NodeClassID = CMS_Class.ClassID
	WHERE CMS_Tree.NodeID = @NodeID
	and CMS_User.UserID = @UserID
	and CMS_Permission.PermissionName = @PermissionName
	and CMS_Role.SiteID = @SiteID
	-- Try to process special roles
	IF (@SelectedUserID IS NULL) OR (@SelectedUserID = 0)
	BEGIN
		DECLARE @SQL varchar(600)
		SET @SQL = 
		'SELECT TOP 1 CMS_Role.RoleID
		FROM CMS_Role
		INNER JOIN CMS_RolePermission on CMS_RolePermission.RoleID = CMS_Role.RoleID
		INNER JOIN CMS_Permission on CMS_Permission.permissionid = CMS_RolePermission.PermissionID
		INNER JOIN CMS_Class on CMS_Class.ClassID = CMS_Permission.ClassID
		INNER JOIN CMS_Tree on CMS_Tree.NodeClassID = CMS_Class.ClassID
		WHERE CMS_Tree.NodeID = ' + CAST(@NodeID AS nvarchar) + ' AND CMS_Permission.PermissionName =''' + @PermissionName + 
		''' AND CMS_Role.RoleName IN (' + @GenericRoles + ') AND CMS_Role.SiteID=' + CAST(@SiteID AS nvarchar)
		EXEC(@SQL)
	END
	ELSE
	SELECT @SelectedUserID
END
GO